from transformers import pipeline
from transformers.tokenization_auto import AutoTokenizer
from transformers.modeling_auto import AutoModelForSequenceClassification
import numpy as np

from typing import Any, List, Iterable

INPUT_COLUMN = "text"

class SentimentExampleModel():
  def __init__(self):

    model = AutoModelForSequenceClassification.from_pretrained("./parameters")
    tokenizer = AutoTokenizer.from_pretrained("./parameters")
    self.classifer = pipeline('sentiment-analysis', model, tokenizer=tokenizer)

  def predict(self, X: np.ndarray, names: Iterable[str]) -> List[Any]:

    model_input = dict(zip(names, X))

    if INPUT_COLUMN not in model_input:
      raise ValueError(f"Input must contain the {INPUT_COLUMN} column")

    classification = self.classifer(model_input[INPUT_COLUMN])

    return [[classification[0]["label"]],[classification[0]["score"]]]